@@ -1,7 +1,7 @@
 """
 Type annotations for datapipeline service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs/)
 
 Usage::
 
@@ -13,7 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence, Union
+from typing import Dict, List, Sequence, Union
+
+from typing_extensions import NotRequired
 
 from .literals import OperatorTypeType, TaskStatusType
 
@@ -30,6 +32,7 @@ __all__ = (
     "CreatePipelineOutputTypeDef",
     "DeactivatePipelineInputRequestTypeDef",
     "DeletePipelineInputRequestTypeDef",
+    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
     "DescribeObjectsInputRequestTypeDef",
     "DescribeObjectsOutputTypeDef",
     "DescribePipelinesInputRequestTypeDef",
@@ -40,6 +43,7 @@ __all__ = (
     "GetPipelineDefinitionInputRequestTypeDef",
     "GetPipelineDefinitionOutputTypeDef",
     "InstanceIdentityTypeDef",
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
     "ListPipelinesInputRequestTypeDef",
     "ListPipelinesOutputTypeDef",
     "OperatorTypeDef",
@@ -54,6 +58,7 @@ __all__ = (
     "PollForTaskOutputTypeDef",
     "PutPipelineDefinitionInputRequestTypeDef",
     "PutPipelineDefinitionOutputTypeDef",
+    "QueryObjectsInputQueryObjectsPaginateTypeDef",
     "QueryObjectsInputRequestTypeDef",
     "QueryObjectsOutputTypeDef",
     "QueryTypeDef",
@@ -163,6 +168,30 @@ DeletePipelineInputRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef",
+    {
+        "pipelineId": str,
+        "objectIds": Sequence[str],
+    },
+)
+_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef",
+    {
+        "evaluateExpressions": bool,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeObjectsInputDescribeObjectsPaginateTypeDef(
+    _RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef,
+    _OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredDescribeObjectsInputRequestTypeDef = TypedDict(
     "_RequiredDescribeObjectsInputRequestTypeDef",
     {
@@ -289,6 +318,14 @@ InstanceIdentityTypeDef = TypedDict(
     total=False,
 )
 
+ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
@@ -456,6 +493,30 @@ PutPipelineDefinitionOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef",
+    {
+        "pipelineId": str,
+        "sphere": str,
+    },
+)
+_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef",
+    {
+        "query": "QueryTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class QueryObjectsInputQueryObjectsPaginateTypeDef(
+    _RequiredQueryObjectsInputQueryObjectsPaginateTypeDef,
+    _OptionalQueryObjectsInputQueryObjectsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredQueryObjectsInputRequestTypeDef = TypedDict(
     "_RequiredQueryObjectsInputRequestTypeDef",
     {
@@ -572,7 +633,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
